package com.ztmap.project.zhny.lotusydqs.mapper;

import java.util.List;
import com.ztmap.project.zhny.lotusydqs.domain.TLotusYdqs;

/**
 * 用电趋势Mapper接口
 * 
 * @author ztmap
 * @date 2023-11-16
 */
public interface TLotusYdqsMapper 
{
    /**
     * 查询用电趋势
     * 
     * @param id 用电趋势ID
     * @return 用电趋势
     */
    public TLotusYdqs selectTLotusYdqsById(Long id);

    /**
     * 查询用电趋势列表
     * 
     * @param tLotusYdqs 用电趋势
     * @return 用电趋势集合
     */
    public List<TLotusYdqs> selectTLotusYdqsList(TLotusYdqs tLotusYdqs);

    /**
     * 新增用电趋势
     * 
     * @param tLotusYdqs 用电趋势
     * @return 结果
     */
    public int insertTLotusYdqs(TLotusYdqs tLotusYdqs);

    /**
     * 修改用电趋势
     * 
     * @param tLotusYdqs 用电趋势
     * @return 结果
     */
    public int updateTLotusYdqs(TLotusYdqs tLotusYdqs);

    /**
     * 删除用电趋势
     * 
     * @param id 用电趋势ID
     * @return 结果
     */
    public int deleteTLotusYdqsById(Long id);

    /**
     * 批量删除用电趋势
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTLotusYdqsByIds(String[] ids);
}
